==> haskell-recaptcha-0.1.0.4-338-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-recaptcha.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recaptcha
version:              0.1.0.4
visibility:           public
id:                   recaptcha-0.1.0.4-EuNHx02lVDr2To6I1UTo4E
key:                  recaptcha-0.1.0.4-EuNHx02lVDr2To6I1UTo4E
license:              BSD-3-Clause
copyright:            (c) 2008 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             http://github.com/jgm/recaptcha/tree/master
synopsis:
    Functions for using the reCAPTCHA service in web applications.

description:
    reCAPTCHA (https://www.google.com/recaptcha/intro/) is a
    service that provides captchas for preventing automated
    spam in web applications.
    recaptcha-hs provides functions for using reCAPTCHA in Haskell
    web applications.

category:             Network
abi:                  350e5c307fcfe580e62c7948be1c15bc
exposed:              True
exposed-modules:      Network.Captcha.ReCaptcha
import-dirs:          /usr/lib/ghc-9.4.8/site-local/recaptcha-0.1.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/recaptcha-0.1.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/recaptcha-0.1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recaptcha
hs-libraries:         HSrecaptcha-0.1.0.4-EuNHx02lVDr2To6I1UTo4E
depends:
    HTTP-4000.4.1-HD8KR4Gj7kDIqhYvZQSDU7 base-4.17.2.1
    network-3.1.4.0-BMQQjwbPvFR57Ka0tgIiy2
    network-uri-2.6.4.2-6dAHdOyJLq76CXdDmIsqEl xhtml-3000.2.2.1

haddock-interfaces:   /usr/share/doc/haskell-recaptcha/html/recaptcha.haddock
haddock-html:         /usr/share/doc/haskell-recaptcha/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-recaptcha-0.1.0.4-364-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-recaptcha.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recaptcha
version:              0.1.0.4
visibility:           public
id:                   recaptcha-0.1.0.4-Gsvox5xRt8bJ28Oix5yEe5
key:                  recaptcha-0.1.0.4-Gsvox5xRt8bJ28Oix5yEe5
license:              BSD-3-Clause
copyright:            (c) 2008 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             http://github.com/jgm/recaptcha/tree/master
synopsis:
    Functions for using the reCAPTCHA service in web applications.

description:
    reCAPTCHA (https://www.google.com/recaptcha/intro/) is a
    service that provides captchas for preventing automated
    spam in web applications.
    recaptcha-hs provides functions for using reCAPTCHA in Haskell
    web applications.

category:             Network
abi:                  d75e42e8d582716d6c21b1e1d54fe4e9
exposed:              True
exposed-modules:      Network.Captcha.ReCaptcha
import-dirs:          /usr/lib/ghc-9.4.8/site-local/recaptcha-0.1.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/recaptcha-0.1.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/recaptcha-0.1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recaptcha
hs-libraries:         HSrecaptcha-0.1.0.4-Gsvox5xRt8bJ28Oix5yEe5
depends:
    HTTP-4000.4.1-I2SHq0OXREm3IzlxzjgUek base-4.17.2.1
    network-3.1.4.0-2g2oEkgQCahBaM3HvlpVNW
    network-uri-2.6.4.2-DVBcu05aYxxCjTvpzOd17v xhtml-3000.2.2.1

haddock-interfaces:   /usr/share/doc/haskell-recaptcha/html/recaptcha.haddock
haddock-html:         /usr/share/doc/haskell-recaptcha/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
